@@ -6,4 +6,8 @@ class Healthcheck():
 
      def healthcheck(self):
         uri = 'healthcheck/status'
-        return APIHelper()._rest_request(uri,"GET")
\ No newline at end of file
+        return APIHelper()._rest_request(uri,"GET")
+
+     def status(self):
+        uri = 'https://api.status.veracode.com/status'
+        return APIHelper()._rest_request(uri,"GET",use_base_url=False)
\ No newline at end of file
